@@ -37,39 +37,6 @@ class Q_DECL_HIDDEN RichTextComposerActions::RichTextComposerActionsPrivate
 public:
     RichTextComposerActionsPrivate(KPIMTextEdit::RichTextComposerControler *controler)
         : composerControler(controler)
-        , action_align_left(nullptr)
-        , action_align_right(nullptr)
-        , action_align_center(nullptr)
-        , action_align_justify(nullptr)
-        , action_direction_ltr(nullptr)
-        , action_direction_rtl(nullptr)
-        , action_text_superscript(nullptr)
-        , action_text_subscript(nullptr)
-        , action_text_bold(nullptr)
-        , action_text_italic(nullptr)
-        , action_text_underline(nullptr)
-        , action_text_strikeout(nullptr)
-        , action_font_family(nullptr)
-        , action_font_size(nullptr)
-        , action_insert_horizontal_rule(nullptr)
-        , action_text_foreground_color(nullptr)
-        , action_text_background_color(nullptr)
-        , action_manage_link(nullptr)
-        , action_list_indent(nullptr)
-        , action_list_dedent(nullptr)
-        , action_list_style(nullptr)
-        , action_paste_quotation(nullptr)
-        , action_add_quote_chars(nullptr)
-        , action_remove_quote_chars(nullptr)
-        , action_paste_without_formatting(nullptr)
-        , action_add_image(nullptr)
-        , action_add_emoticon(nullptr)
-        , action_insert_html(nullptr)
-        , action_add_table(nullptr)
-        , action_delete_line(nullptr)
-        , action_format_reset(nullptr)
-        , action_format_painter(nullptr)
-        , richTextEnabled(false)
     {
     }
 
@@ -358,7 +325,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
             d->composerControler, &RichTextComposerControler::manageLink);
 
     d->action_list_indent = new QAction(QIcon::fromTheme(QStringLiteral("format-indent-more")),
-                                        i18nc("@action", "Increase Indent"), this);
+                                        i18nc("@action", "Increase List Level"), this);
     d->richTextActionList.append((d->action_list_indent));
     d->action_list_indent->setObjectName(QStringLiteral("format_list_indent_more"));
     if (ac) {
@@ -369,7 +336,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_list_indent, &QAction::triggered,
             this, &RichTextComposerActions::slotUpdateMiscActions);
     d->action_list_dedent = new QAction(QIcon::fromTheme(QStringLiteral("format-indent-less")),
-                                        i18nc("@action", "Decrease Indent"), this);
+                                        i18nc("@action", "Decrease List Level"), this);
     d->richTextActionList.append((d->action_list_dedent));
     d->action_list_dedent->setObjectName(QStringLiteral("format_list_indent_less"));
     if (ac) {
