@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,29 +22,25 @@
 #define RICHTEXTCOMPOSER_INSERTHTMLDIALOG_H
 
 #include <QDialog>
-#include "config-kpimtextedit.h"
 
-#include "kpimtextedit_export.h"
+#include "kpimtextedit_private_export.h"
 #include "kpimtextedit/plaintexteditor.h"
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class InsertHtmlDialogPrivate;
-class KPIMTEXTEDIT_EXPORT InsertHtmlDialog : public QDialog
+class KPIMTEXTEDIT_TESTS_EXPORT InsertHtmlDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit InsertHtmlDialog(QWidget *parent = nullptr);
     ~InsertHtmlDialog();
-    QString html() const;    
+    QString html() const;
     void setSelectedText(const QString &str);
 
 private:
     friend class InsertHtmlDialogPrivate;
     InsertHtmlDialogPrivate *const d;
-    Q_PRIVATE_SLOT(d, void _k_slotTextChanged())
 };
-
 }
 
 #endif
