@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -34,7 +34,7 @@ class InsertHtmlEditor : public KPIMTextEdit::PlainTextEditor
     Q_OBJECT
 public:
     explicit InsertHtmlEditor(QWidget *parent = nullptr);
-    ~InsertHtmlEditor();
+    ~InsertHtmlEditor() override;
 protected:
     void keyPressEvent(QKeyEvent *e) override;
 private:
