@@ -59,11 +59,6 @@ public:
         : q(qq)
         , mTextIndicator(new KPIMTextEdit::TextMessageIndicator(q))
         , webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q))
-        , richTextDecorator(nullptr)
-        , speller(nullptr)
-        , mInitialFontSize(0)
-        , customPalette(false)
-        , activateLanguageMenu(true)
     {
         KConfig sonnetKConfig(QStringLiteral("sonnetrc"));
         KConfigGroup group(&sonnetKConfig, "Spelling");
@@ -92,9 +87,9 @@ public:
     QTextDocumentFragment originalDoc;
     PlainTextEditor::SupportFeatures supportFeatures;
     int mInitialFontSize = 0;
-    bool customPalette;
-    bool activateLanguageMenu;
-    bool checkSpellingEnabled;
+    bool customPalette = false;
+    bool activateLanguageMenu = true;
+    bool checkSpellingEnabled = false;
 };
 
 PlainTextEditor::PlainTextEditor(QWidget *parent)
@@ -649,7 +644,7 @@ void PlainTextEditor::moveLineUpDown(bool moveUp)
         move.setPosition(cursor.selectionStart());
         move.movePosition(QTextCursor::StartOfBlock);
         move.setPosition(cursor.selectionEnd(), QTextCursor::KeepAnchor);
-        move.movePosition(move.atBlockStart() ? QTextCursor::Left: QTextCursor::EndOfBlock,
+        move.movePosition(move.atBlockStart() ? QTextCursor::Left : QTextCursor::EndOfBlock,
                           QTextCursor::KeepAnchor);
     } else {
         move.movePosition(QTextCursor::StartOfBlock);
